@@ -749,8 +749,8 @@ static ptr s_system(const char *s) {
 #ifdef WIN32
   return Sinteger(status);
 #else
-  if WIFEXITED(status) return Sinteger(WEXITSTATUS(status));
-  if WIFSIGNALED(status) return Sinteger(-WTERMSIG(status));
+  if (WIFEXITED(status)) return Sinteger(WEXITSTATUS(status));
+  if (WIFSIGNALED(status)) return Sinteger(-WTERMSIG(status));
   S_error("system", "cannot determine subprocess exit status");
   return 0 /* not reached */;
 #endif /* WIN32 */
@@ -1472,25 +1472,20 @@ static double s_pow(double x, double y) { return pow(x, y); }
 #endif /* i3fb/ti3fb */
 
 #ifdef __MINGW32__
-/* cos() and sin() do not handle large values nicely,
-   so use fmod() to get reasonably close */
-# define INTO_SINCOS_RANGE(x) (((x > 1e9) || (x < -1e9)) \
-			       ? fmod(x, 2*atan2(0.0, -1.0)) \
-			       : x)
 /* asinh() and atanh() sometimes get zero sign wrong */
 # define CHECK_ASINTAN_ZERO(x, e) ((x == 0.0) \
                                    ? (signbit(x) ? -0.0 : 0.0)  \
                                    : e)
+/* see also "mingw.zuo" */
 #else
-# define INTO_SINCOS_RANGE(x) x
 # define CHECK_ASINTAN_ZERO(x, e) e
 #endif
 
 static double s_sqrt(double x) { return sqrt(x); }
 
-static double s_sin(double x) { return sin(INTO_SINCOS_RANGE(x)); }
+static double s_sin(double x) { return sin(x); }
 
-static double s_cos(double x) { return cos(INTO_SINCOS_RANGE(x)); }
+static double s_cos(double x) { return cos(x); }
 
 static double s_tan(double x) { return tan(x); }
 
